==> s10s_card_scanner-0.0.3.tar.gz: android/src/main/kotlin/com/example/s10s_card_scanner/S10sCardScannerPlugin.kt <==
package com.example.s10s_card_scanner

import android.app.Activity
import android.content.Intent
import androidx.annotation.NonNull
import cards.pay.paycardsrecognizer.sdk.Card
import cards.pay.paycardsrecognizer.sdk.ScanCardIntent

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry
import io.flutter.plugin.common.PluginRegistry.Registrar
import io.flutter.plugin.common.PluginRegistry.ActivityResultListener
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding

class S10sCardScannerPlugin : FlutterPlugin, MethodCallHandler, ActivityAware, PluginRegistry.ActivityResultListener {

  private val CHANNEL_NAME = "s10s/cardScanner"
  private val REQUEST_CODE_SCAN_CARD = 11
  private lateinit var activity: Activity
  private lateinit var channel: MethodChannel
  private var channelResult: MethodChannel.Result? = null

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, CHANNEL_NAME)
    channel.setMethodCallHandler(this)
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    channelResult = result
    when (call.method) {
      "scanCard" -> {
        val intent: Intent = ScanCardIntent.Builder(activity).build()
        activity.startActivityForResult(intent, REQUEST_CODE_SCAN_CARD)
      }
      else -> result.notImplemented()
    }
  }

  override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?): Boolean {
    if (requestCode == REQUEST_CODE_SCAN_CARD) {
      if (resultCode == Activity.RESULT_OK) {
        val card: Card? = data?.getParcelableExtra(ScanCardIntent.RESULT_PAYCARDS_CARD)
        val map = hashMapOf<String, String?>().apply {
          this["cardNumber"] = card?.cardNumber
          this["expirationDate"] = card?.expirationDate
          this["cardHolderName"] = card?.cardHolderName
        }
        channelResult?.success(map)
        return true
      }
    }
    return false
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    activity = binding.activity;
  }

  override fun onDetachedFromActivity() {}

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {}

  override fun onDetachedFromActivityForConfigChanges() {}
}

==> s10s_card_scanner-0.1.0.tar.gz: android/src/main/kotlin/com/example/s10s_card_scanner/S10sCardScannerPlugin.kt <==
package com.example.s10s_card_scanner

import android.app.Activity
import android.content.Intent
import androidx.annotation.NonNull
import cards.pay.paycardsrecognizer.sdk.Card
import cards.pay.paycardsrecognizer.sdk.ScanCardIntent

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry
import io.flutter.plugin.common.PluginRegistry.Registrar
import io.flutter.plugin.common.PluginRegistry.ActivityResultListener
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import android.util.Log

class S10sCardScannerPlugin : FlutterPlugin, MethodCallHandler, ActivityAware, PluginRegistry.ActivityResultListener {

  private val CHANNEL_NAME = "s10s/cardScanner"
  private val REQUEST_CODE_SCAN_CARD = 11
  private lateinit var activity: Activity
  private lateinit var channel: MethodChannel
  private var channelResult: MethodChannel.Result? = null
  private var activityPluginBinding: ActivityPluginBinding? = null

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, CHANNEL_NAME)
    channel.setMethodCallHandler(this)
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    channelResult = result
    when (call.method) {
      "scanCard" -> {
        val intent: Intent = ScanCardIntent.Builder(activity).build()
        activity.startActivityForResult(intent, REQUEST_CODE_SCAN_CARD)
      }
      else -> result.notImplemented()
    }
  }

  override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?): Boolean {

    if (requestCode == REQUEST_CODE_SCAN_CARD) {
      if (resultCode == Activity.RESULT_OK) {
        val card: Card? = data?.getParcelableExtra(ScanCardIntent.RESULT_PAYCARDS_CARD)
        val map = hashMapOf<String, String?>().apply {
          this["cardNumber"] = card?.cardNumber
          this["expirationDate"] = card?.expirationDate
          this["cardHolderName"] = card?.cardHolderName
        }
        channelResult?.success(map)
        return true
      } else {
        Log.d("#######", data.toString())
      }
    }
    return false
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    activity = binding.activity;
    activityPluginBinding = binding
    binding.addActivityResultListener(this)
  }

  override fun onDetachedFromActivity() {
    activityPluginBinding?.removeActivityResultListener(this)
    activityPluginBinding = null
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {}

  override fun onDetachedFromActivityForConfigChanges() {}
}
